@@ -35,23 +35,47 @@ class DateTime(types.TypeDecorator):
             return value.strftime("%Y-%m-%d %H:%M:%S.%f")
 
 
-class FixedBool(types.TypeDecorator):
+class BoolField(types.TypeDecorator):
     impl = types.Boolean
+    # NOTE: origin `sqltypes.Boolean` use _strict_bools = frozenset([None, True, False])
+
+    BoolStrings = {
+        ""     : False,
+        "0"    : False,
+        "false": False,
+        "null" : False,
+        "none" : False,
+        "no"   : False,
+        "n"    : False,
+        "f"    : False,
+        # "1"    : True,
+        # "true" : True,
+        # "yes"  : True,
+        # "ok"   : True,
+        # "y"    : True,
+        # "t"    : True,
+    }
 
     def process_bind_param(self, value, dialect):
-        if value in ["0", 0, "false", "False"]:
-            value = False
-        elif value in ["1", 1, "true", "True"]:
-            value = True
-        return value
+        if isinstance(value, str):
+            v = value.strip().lower()
+            return self.BoolStrings.get(v, True)
+        else:
+            return bool(value)
 
 
 class TrimString(types.TypeDecorator):
     impl = types.String
 
     def process_bind_param(self, value, dialect):
-        if value and isinstance(value, str):
+        if isinstance(value, str):
             value = value.strip()
+        elif value is None:
+            return ""
+        else:
+            value = str(value)
+        if self.impl.length > 0 and len(value) > self.impl.length:
+            value = value[-self.impl.length:]
         return value
 
 
@@ -61,9 +85,25 @@ class StringTags(types.TypeDecorator):
     def process_bind_param(self, value, dialect):
         if value and isinstance(value, str):
             return ','.join(map(lambda x: x.strip(), value.split(',')))
+        if isinstance(value, (list, tuple, set)):
+            return ','.join(map(str, value))
         return ""
 
 
+class SortedTags(types.TypeDecorator):
+    impl = types.JSON
+
+    def process_bind_param(self, value, dialect):
+        if isinstance(value, (list, tuple, set)):
+            return sorted(set(map(str, value)))
+        elif isinstance(value, str):
+            return sorted(set(map(lambda x: x.strip(), value.split(','))))
+        elif not value:
+            return []
+        else:
+            return [str(value)]
+
+
 class OrderedJson(types.TypeDecorator):
     impl = types.JSON
 
